@@ -98,30 +98,35 @@ class SQLiteDb(object):
     and of parameters named "accountS" should be an iterable like list()
     """
 
-    def __init__(self, db_path, local_tz, default_tz, debug=False):
+    _calendars = []
+
+    def __init__(self, calendar, db_path, local_tz, default_tz,
+                 color=None, readonly=False, unicode_symbols=True,
+                 debug=False):
 
         if db_path is None:
             db_path = xdg.BaseDirectory.save_data_path('khal') + '/khal.db'
         self.db_path = path.expanduser(db_path)
+        self.calendar = calendar
         self._create_dbdir()
         self.local_tz = local_tz
         self.default_tz = default_tz
         self.conn = sqlite3.connect(self.db_path)
         self.cursor = self.conn.cursor()
+        self.color = color
+        self.readonly = readonly
+        self.unicode_symbols = unicode_symbols
         self.debug = debug
         self._create_default_tables()
         self._check_table_version()
-        self._accounts = []
+
+        if not self.calendar in self._calendars or db_path == ':memory:':
+                self.create_account_table()
+                self._calendars.append(self.calendar)
 
     def __del__(self):
         self.conn.close()
 
-    def _dump(self, account):
-        """return table self.account, used for testing"""
-        sql_s = 'SELECT * FROM {0}'.format(account + '_m')
-        result = self.sql_ex(sql_s)
-        return result
-
     def _create_dbdir(self):
         """create the dbdir if it doesn't exist"""
         if self.db_path == ':memory:':
@@ -178,13 +183,6 @@ class SQLiteDb(object):
         self.conn.commit()
         self._check_table_version()  # insert table version
 
-    def _check_account(self, account):
-        if account in self._accounts:
-            return
-        else:
-            self.create_account_table(account)
-            self._accounts.append(account)
-
     def sql_ex(self, statement, stuple='', commit=True):
         """wrapper for sql statements, does a "fetchall" """
         self.cursor.execute(statement, stuple)
@@ -193,10 +191,10 @@ class SQLiteDb(object):
             self.conn.commit()
         return result
 
-    def create_account_table(self, account):
+    def create_account_table(self):
         count_sql_s = """SELECT count(*) FROM accounts
                 WHERE account = ? AND resource = ?"""
-        stuple = (account, '')
+        stuple = (self.calendar, '')
         self.cursor.execute(count_sql_s, stuple)
         result = self.cursor.fetchone()
 
@@ -206,42 +204,39 @@ class SQLiteDb(object):
                 href TEXT UNIQUE,
                 etag TEXT,
                 vevent TEXT
-                )""".format(account + '_m')
+                )""".format(self.calendar + '_m')
         self.sql_ex(sql_s)
         sql_s = '''CREATE TABLE IF NOT EXISTS {0} (
             dtstart INT,
             dtend INT,
-            href TEXT ); '''.format(account + '_dt')
+            href TEXT ); '''.format(self.calendar + '_dt')
         self.sql_ex(sql_s)
         sql_s = '''CREATE TABLE IF NOT EXISTS {0} (
             dtstart INT,
             dtend INT,
-            href TEXT ); '''.format(account + '_d')
+            href TEXT ); '''.format(self.calendar + '_d')
         self.sql_ex(sql_s)
         sql_s = 'INSERT INTO accounts (account, resource) VALUES (?, ?)'
-        stuple = (account, '')
+        stuple = (self.calendar, '')
         self.sql_ex(sql_s, stuple)
-        logger.debug("made sure tables for {0} exists".format(account))
+        logger.debug("made sure tables for {0} exists".format(self.calendar))
 
-    def needs_update(self, account, href_etag_list):
+    def needs_update(self, href_etag_list):
         """checks if we need to update this vcard
-        :param account: account
-        :param account: string
         :param href_etag_list: list of tuples of (hrefs and etags)
         :return: list of hrefs that need an update
         """
-        self._check_account(account)
         needs_update = list()
         for href, etag in href_etag_list:
             stuple = (href,)
             sql_s = 'SELECT etag FROM {0} WHERE href = ?'.format(
-                account + '_m')
+                self.calendar + '_m')
             result = self.sql_ex(sql_s, stuple)
             if not result or etag != result[0][0]:
                 needs_update.append(href)
         return needs_update
 
-    def update(self, vevent, account, href=None, etag='',
+    def update(self, vevent, href=None, etag='',
                ignore_invalid_items=False):
         """insert a new or update an existing card in the db
 
@@ -269,7 +264,6 @@ class SQLiteDb(object):
         """
         if href is None:
             raise ValueError('href may not be one')
-        self._check_account(account)
         events = []
         if not isinstance(vevent, icalendar.cal.Event):
             ical = icalendar.Event.from_ical(vevent)
@@ -304,7 +298,7 @@ class SQLiteDb(object):
                                            self.default_tz,
                                            href)
 
-        for dbname in [account + '_d', account + '_dt']:
+        for dbname in [self.calendar + '_d', self.calendar + '_dt']:
             sql_s = ('DELETE FROM {0} WHERE href == ?'.format(dbname))
             self.sql_ex(sql_s, (href, ), commit=False)
 
@@ -312,7 +306,7 @@ class SQLiteDb(object):
             if all_day_event:
                 dbstart = dtstart.strftime('%Y%m%d')
                 dbend = dtend.strftime('%Y%m%d')
-                dbname = account + '_d'
+                dbname = self.calendar + '_d'
             else:
                 # TODO: extract strange (aka non Olson) TZs from params['TZID']
                 # perhaps better done in event/vevent
@@ -325,7 +319,7 @@ class SQLiteDb(object):
                 dtend_utc = dtend.astimezone(pytz.UTC)
                 dbstart = calendar.timegm(dtstart_utc.timetuple())
                 dbend = calendar.timegm(dtend_utc.timetuple())
-                dbname = account + '_dt'
+                dbname = self.calendar + '_dt'
 
             sql_s = ('INSERT INTO {0} '
                      '(dtstart, dtend, href) '
@@ -339,7 +333,7 @@ class SQLiteDb(object):
                  '(vevent, etag, href) '
                  'VALUES (?, ?, '
                  'COALESCE((SELECT href FROM {0} WHERE href = ?), ?)'
-                 ');'.format(account + '_m'))
+                 ');'.format(self.calendar + '_m'))
 
         stuple = (vevent.to_ical().decode('utf-8'),
                   etag,
@@ -348,8 +342,8 @@ class SQLiteDb(object):
         self.sql_ex(sql_s, stuple, commit=False)
         self.conn.commit()
 
-    def get_ctag(self, account):
-        stuple = (account, )
+    def get_ctag(self):
+        stuple = (self.calendar, )
         sql_s = 'SELECT ctag FROM accounts WHERE account = ?'
         try:
             ctag = self.sql_ex(sql_s, stuple)[0][0]
@@ -357,87 +351,55 @@ class SQLiteDb(object):
         except IndexError:
             return None
 
-    def set_ctag(self, account, ctag):
-        stuple = (ctag, account, )
+    def set_ctag(self, ctag):
+        stuple = (ctag, self.calendar, )
         sql_s = 'UPDATE accounts SET ctag = ? WHERE account = ?'
         self.sql_ex(sql_s, stuple)
         self.conn.commit()
 
-    def update_href(self, oldhref, newhref, account, etag=''):
-        """updates old_href to new_href, can also alter etag,
-        see update() for an explanation of these parameters"""
-        self._check_account(account)
-        stuple = (newhref, etag, oldhref)
-        sql_s = 'UPDATE {0} SET href = ?, etag = ?, \
-             WHERE href = ?;'.format(account + '_m')
-        self.sql_ex(sql_s, stuple)
-        for dbname in [account + '_d', account + '_dt']:
-            sql_s = 'UPDATE {0} SET href = ? WHERE href = ?;'.format(dbname)
-            self.sql_ex(sql_s, (newhref, oldhref))
-
-    def href_exists(self, href, account):
-        """returns True if href already exists in db
-
-        :param href: href
-        :type href: str()
-        :returns: True or False
-        """
-        self._check_account(account)
-        sql_s = 'SELECT href FROM {1} WHERE href = ?;'.format(account)
-        if len(self.sql_ex(sql_s, (href, ))) == 0:
-            return False
-        else:
-            return True
-
-    def get_etag(self, href, account):
+    def get_etag(self, href):
         """get etag for href
 
         type href: str()
         return: etag
         rtype: str()
         """
-        self._check_account(account)
-        sql_s = 'SELECT etag FROM {0} WHERE href=(?);'.format(account + '_m')
+        sql_s = 'SELECT etag FROM {0} WHERE href=(?);'.format(self.calendar + '_m')
         try:
             etag = self.sql_ex(sql_s, (href,))[0][0]
             return etag
         except IndexError:
             return None
 
-    def delete(self, href, account):
+    def delete(self, href, etag=None):
         """
         removes the event from the db,
         returns nothing
+        :param etag: only there for compatiblity with vdirsyncer's Storage,
+                     we always delete
         """
-        self._check_account(account)
-        for dbname in [account + '_d', account + '_dt', account + '_m']:
+        for dbname in [self.calendar + '_d', self.calendar + '_dt', self.calendar + '_m']:
             sql_s = 'DELETE FROM {0} WHERE href = ? ;'.format(dbname)
             self.sql_ex(sql_s, (href, ))
 
-    def get_all_href_from_db(self, accounts):
-        """returns a list with all hrefs
+    def list(self):
         """
-        result = list()
-        for account in accounts:
-            self._check_account(account)
-            hrefs = self.sql_ex('SELECT href FROM {0}'.format(account + '_m'))
-            result = result + [(href[0], account) for href in hrefs]
-        return result
+        :returns: list of (href, etag)
+        """
+        return self.sql_ex('SELECT href, etag FROM {0}_m'.format(self.calendar))
 
-    def get_time_range(self, start, end, account, color='', readonly=False,
-                       unicode_symbols=True, show_deleted=True):
+    def get_time_range(self, start, end, show_deleted=True):
         """returns
         :type start: datetime.datetime
         :type end: datetime.datetime
         :param deleted: include deleted events in returned lsit
         """
-        self._check_account(account)
         start = time.mktime(start.timetuple())
         end = time.mktime(end.timetuple())
         sql_s = ('SELECT href, dtstart, dtend FROM {0} WHERE '
                  'dtstart >= ? AND dtstart <= ? OR '
                  'dtend >= ? AND dtend <= ? OR '
-                 'dtstart <= ? AND dtend >= ?').format(account + '_dt')
+                 'dtstart <= ? AND dtend >= ?').format(self.calendar + '_dt')
         stuple = (start, end, start, end, start, end)
         result = self.sql_ex(sql_s, stuple)
         event_list = list()
@@ -445,22 +407,13 @@ class SQLiteDb(object):
             start = pytz.UTC.localize(
                 datetime.datetime.utcfromtimestamp(start))
             end = pytz.UTC.localize(datetime.datetime.utcfromtimestamp(end))
-            event = self.get_vevent_from_db(href, account,
-                                            start=start, end=end,
-                                            color=color,
-                                            readonly=readonly,
-                                            unicode_symbols=unicode_symbols)
+            event = self.get(href, start=start, end=end)
             event_list.append(event)
         return event_list
 
-    def get_allday_range(self, start, end=None, account=None, color='',
-                         readonly=False, unicode_symbols=True,
-                         show_deleted=True):
+    def get_allday_range(self, start, end=None, show_deleted=True):
         # TODO type check on start and end
         # should be datetime.date not datetime.datetime
-        self._check_account(account)
-        if account is None:
-            raise Exception('need to specify an account')
         strstart = start.strftime('%Y%m%d')
         if end is None:
             end = start + datetime.timedelta(days=1)
@@ -468,7 +421,7 @@ class SQLiteDb(object):
         sql_s = ('SELECT href, dtstart, dtend FROM {0} WHERE '
                  'dtstart >= ? AND dtstart < ? OR '
                  'dtend > ? AND dtend <= ? OR '
-                 'dtstart <= ? AND dtend > ? ').format(account + '_d')
+                 'dtstart <= ? AND dtend > ? ').format(self.calendar + '_d')
         stuple = (strstart, strend, strstart, strend, strstart, strend)
         result = self.sql_ex(sql_s, stuple)
         event_list = list()
@@ -477,53 +430,11 @@ class SQLiteDb(object):
             end = time.strptime(str(end), '%Y%m%d')
             start = datetime.date(start.tm_year, start.tm_mon, start.tm_mday)
             end = datetime.date(end.tm_year, end.tm_mon, end.tm_mday)
-            event = self.get_vevent_from_db(href, account,
-                                            start=start, end=end,
-                                            color=color,
-                                            readonly=readonly,
-                                            unicode_symbols=unicode_symbols)
+            event = self.get(href, start=start, end=end)
             event_list.append(event)
         return event_list
 
-    def hrefs_by_time_range_datetime(self, start, end, account, color=''):
-        """returns
-        :type start: datetime.datetime
-        :type end: datetime.datetime
-        """
-        self._check_account(account)
-        start = time.mktime(start.timetuple())
-        end = time.mktime(end.timetuple())
-        sql_s = ('SELECT href FROM {0} WHERE '
-                 'dtstart >= ? AND dtstart <= ? OR '
-                 'dtend >= ? AND dtend <= ? OR '
-                 'dtstart <= ? AND dtend >= ?').format(account + '_dt')
-        stuple = (start, end, start, end, start, end)
-        result = self.sql_ex(sql_s, stuple)
-        return [one[0] for one in result]
-
-    def hrefs_by_time_range_date(self, start, end=None, account=None):
-        self._check_account(account)
-        if account is None:
-            raise Exception('need to specify an account')
-        strstart = start.strftime('%Y%m%d')
-        if end is None:
-            end = start + datetime.timedelta(days=1)
-        strend = end.strftime('%Y%m%d')
-        sql_s = ('SELECT href FROM {0} WHERE '
-                 'dtstart >= ? AND dtstart < ? OR '
-                 'dtend > ? AND dtend <= ? OR '
-                 'dtstart <= ? AND dtend > ? ').format(account + '_d')
-        stuple = (strstart, strend, strstart, strend, strstart, strend)
-        result = self.sql_ex(sql_s, stuple)
-        return [one[0] for one in result]
-
-    def hrefs_by_time_range(self, start, end, account):
-        return list(set(self.hrefs_by_time_range_date(start, end, account) +
-                    self.hrefs_by_time_range_datetime(start, end, account)))
-
-    def get_vevent_from_db(self, href, account, start=None, end=None,
-                           readonly=False, color=lambda x: x,
-                           unicode_symbols=True):
+    def get(self, href, start=None, end=None):
         """returns the Event matching href, if start and end are given, a
         specific Event from a Recursion set is returned, the Event as saved in
         the db
@@ -531,21 +442,20 @@ class SQLiteDb(object):
         All other parameters given to this function are handed over to the
         Event.
         """
-        self._check_account(account)
         sql_s = 'SELECT vevent, etag FROM {0} WHERE href=(?)'.format(
-            account + '_m')
+            self.calendar + '_m')
         result = self.sql_ex(sql_s, (href, ))
         return Event(result[0][0],
                      local_tz=self.local_tz,
                      default_tz=self.default_tz,
                      start=start,
                      end=end,
-                     color=color,
+                     color=self.color,
                      href=href,
-                     account=account,
-                     readonly=readonly,
+                     calendar=self.calendar,
+                     readonly=self.readonly,
                      etag=result[0][1],
-                     unicode_symbols=unicode_symbols)
+                     unicode_symbols=self.unicode_symbols)
 
 
 def get_random_href():
