@@ -38,33 +38,37 @@ from vdirsyncer.storage import FilesystemStorage
 from . import backend
 from .event import Event
 from .. import log
-from .exceptions import UnsupportedFeatureError
+from .exceptions import UnsupportedFeatureError, ReadOnlyCalendarError
 
 logger = log.logger
 
 
-class BaseCalendar(object):
-
-    """base class for Calendar and CalendarCollection"""
-
-    def get_by_time_range(self, start, end):
-        raise NotImplementedError
-
-    def get_allday_by_time_range(self, start, end):
-        raise NotImplementedError
-
-    def get_datetime_by_time_range(self, start, end):
-        raise NotImplementedError
-
-    def sync(self):
-        raise NotImplementedError
-
-
 class Calendar(object):
 
     def __init__(self, name, dbpath, path, readonly=False, color='',
                  unicode_symbols=True, default_tz=None,
                  local_tz=None, debug=True):
+        """
+        :param name: the name of the calendar
+        :type name: str
+        :param dbpath: path where the local chaching db should be saved
+        :type dbpath: str
+        :param readonly: if True, this Calendar cannot be modified
+        :type readonly: bool
+        :param color: the color which this calendar's events should be
+                      printed in
+        :type color: str
+        :param unicode_symbols: if True, unicode symbols will be used for
+                                representing this calendars's events properties
+        :type unicode_symbols: bool
+        :param default_tz: timezone used by default
+        :tpye default_tz: pytz.timezone
+        :param local_tz: the timezone this calendar's event's times should be
+                         shown in
+        :type local_tz: pytz.timezone
+        :param debug: if True, some debugging information will be printed
+        :type debug: bool
+        """
 
         self._default_tz = default_tz
         self._local_tz = default_tz if local_tz is None else local_tz
@@ -73,9 +77,12 @@ class Calendar(object):
         self.path = os.path.expanduser(path)
         self._debug = debug
         self._dbtool = backend.SQLiteDb(
+            self.name,
             dbpath,
             default_tz=self._default_tz,
             local_tz=self._local_tz,
+            color=self.color,
+            readonly=readonly,
             debug=self._debug)
         self._storage = FilesystemStorage(path, '.ics')
         self._readonly = readonly
@@ -88,28 +95,16 @@ class Calendar(object):
         return os.path.getmtime(self.path)
 
     def get_by_time_range(self, start, end, show_deleted=False):
-        return self._dbtool.get_time_range(start,
-                                           end,
-                                           self.name,
-                                           self.color,
-                                           self._readonly,
-                                           self._unicode_symbols,
-                                           show_deleted)
+        return self._dbtool.get_time_range(start, end, show_deleted)
 
     def get_allday_by_time_range(self, start, end=None, show_deleted=False):
-        return self._dbtool.get_allday_range(
-            start, end, self.name, self.color, self._readonly,
-            self._unicode_symbols, show_deleted)
+        return self._dbtool.get_allday_range(start, end, show_deleted)
 
     def get_datetime_by_time_range(self, start, end, show_deleted=False):
-        return self._dbtool.get_time_range(
-            start, end, self.name, self.color, self._readonly,
-            self._unicode_symbols, show_deleted)
+        return self._dbtool.get_time_range(start, end, show_deleted)
 
     def get_event(self, href):
-        return self._dbtool.get_vevent_from_db(
-            href, self.name, color=self.color, readonly=self._readonly,
-            unicode_symbols=self._unicode_symbols)
+        return self._dbtool.get(href)
 
     def update(self, event):
         """update an event in the database
@@ -117,6 +112,8 @@ class Calendar(object):
         param event: the event that should be updated
         type event: event.Event
         """
+        if self._readonly:
+            raise ReadOnlyCalendarError()
         if event.etag is None:
             self.new(event)
         else:
@@ -137,15 +134,16 @@ class Calendar(object):
         param event: the event that should be updated
         type event: event.Event
         """
+        if self._readonly:
+            raise ReadOnlyCalendarError()
         href, etag = self._storage.upload(event)
         event.href = href
         event.etag = etag
         try:
             self._dbtool.update(event.to_ical(),
-                                self.name,
                                 href=href,
                                 etag=etag)
-            self._dbtool.set_ctag(self.name, self.local_ctag())
+            self._dbtool.set_ctag(self.local_ctag())
         except Exception as error:
             logger.error(
                 'Failed to parse vcard {} during new in collection '
@@ -155,11 +153,13 @@ class Calendar(object):
     def delete(self, event):
         """delete event from this collection
         """
+        if self._readonly:
+            raise ReadOnlyCalendarError()
         self._storage.delete(event.href, event.etag)
-        self._dbtool.delete(event.href, event.account)
+        self._dbtool.delete(event.href)
 
     def _db_needs_update(self):
-        if self.local_ctag() == self._dbtool.get_ctag(self.name):
+        if self.local_ctag() == self._dbtool.get_ctag():
             return False
         else:
             return True
@@ -169,17 +169,23 @@ class Calendar(object):
 
         should be called after every change to the vdir
         """
-        status = True
+        storage_hrefs = list()
         for href, etag in self._storage.list():
-            if etag != self._dbtool.get_etag(href, self.name):
-                status = status and self.update_vevent(href)
-        if status:
-            self._dbtool.set_ctag(self.name, self.local_ctag())
+            storage_hrefs.append(href)
+            if etag != self._dbtool.get_etag(href):
+                self._update_vevent(href)
+        db_hrefs = [href for href, etag in self._dbtool.list()]
+        for href in set(db_hrefs) - set(storage_hrefs):
+            self._dbtool.delete(href)
 
-    def update_vevent(self, href):
+        self._dbtool.set_ctag(self.local_ctag())
+
+    def _update_vevent(self, href):
+        """should only be called during db_update, does not check for
+        readonly"""
         event, etag = self._storage.get(href)
         try:
-            self._dbtool.update(event.raw, self.name, href=href, etag=etag,
+            self._dbtool.update(event.raw, href=href, etag=etag,
                                 ignore_invalid_items=True)
             return True
         except Exception as error:
@@ -195,7 +201,7 @@ class Calendar(object):
     def new_event(self, ical, local_tz, default_tz):
         """creates and returns (but does not insert) new event from ical
         string"""
-        return Event(ical=ical, account=self.name, local_tz=local_tz,
+        return Event(ical=ical, calendar=self.name, local_tz=local_tz,
                      default_tz=default_tz)
 
 
@@ -213,12 +219,18 @@ class CalendarCollection(object):
     def names(self):
         return self._calnames.keys()
 
+    @property
+    def writable_names(self):
+        return [cal for cal in self._calnames if not self._calnames[cal]._readonly]
+
     @property
     def default_calendar_name(self):
         if self._default_calendar_name in self.names:
             return self._default_calendar_name
+        elif len(self.writable_names) > 0:
+            return self.writable_names[0]
         else:
-            return self.names[0]
+            return self._calnames.values()[0].name
 
     def append(self, calendar):
         self._calnames[calendar.name] = calendar
@@ -244,22 +256,22 @@ class CalendarCollection(object):
         return events
 
     def update(self, event):
-        self._calnames[event.account].update(event)
+        self._calnames[event.calendar].update(event)
 
     def new(self, event, collection=None):
         if collection:
             self._calnames[collection].new(event)
         else:
-            self._calnames[event.account].new(event)
+            self._calnames[event.calendar].new(event)
 
     def delete(self, event):
-        self._calnames[event.account].delete(event)
+        self._calnames[event.calendar].delete(event)
 
-    def get_event(self, href, account):
-        return self._calnames[account].get_event(href)
+    def get_event(self, href, calendar):
+        return self._calnames[calendar].get_event(href)
 
     def change_collection(self, event, new_collection):
-        self._calnames[event.account].delete(event)
+        self._calnames[event.calendar].delete(event)
         self._calnames[new_collection].new(event)
         # TODO would be better to first add to new collection, then delete
         # currently not possible since new modifies event.etag
