@@ -64,6 +64,9 @@ class AccountChooser(urwid.PopUpLauncher):
     does NOT handle the actual moving of an event to another account"""
 
     def __init__(self, active_account, accounts):
+        if accounts == list():
+            accounts = active_account = ['no writable calendars']
+
         self.active_account = active_account
         self.original_account = active_account
         self.accounts = accounts
@@ -344,7 +347,7 @@ class U_Event(urwid.Text):
 
     @property
     def uid(self):
-        return self.event.account + '\n' + str(self.event.href)
+        return self.event.calendar + '\n' + str(self.event.href)
 
     def set_title(self, mark=''):
         if self.uid in self.eventcolumn.deleted:
@@ -580,7 +583,7 @@ class EventDisplay(EventViewer):
                                         ' To: ' + endstr))
 
         # resource
-        lines.append(urwid.Text('Calendar: ' + event.account))
+        lines.append(urwid.Text('Calendar: ' + event.calendar))
 
         # description and location
         for key, desc in [('DESCRIPTION', 'Desc'), ('LOCATION', 'Loc')]:
@@ -631,8 +634,9 @@ class EventEditor(EventViewer):
         self.recursioneditor = RecursionEditor(rrule)
         self.summary = urwid.Edit(
             edit_text=event.vevent['SUMMARY'])
-        self.accountchooser = AccountChooser(self.event.account,
-                                             self.collection.names)
+        # TODO warning message if len(self.collection.writable_names) == 0
+        self.accountchooser = AccountChooser(self.event.calendar,
+                                             self.collection.writable_names)
         accounts = CColumns([(9, urwid.Text(u'Calendar: ')),
                              self.accountchooser])
         self.description = urwid.Edit(caption=u'Description: ',
@@ -738,7 +742,7 @@ class EventEditor(EventViewer):
             self.event.allday = self.startendeditor.allday
             if self.event.etag is None:  # has not been saved before
                 # TODO look for better way to detect this
-                self.event.account = self.accountchooser.account
+                self.event.calendar = self.accountchooser.account
                 self.collection.new(self.event)
             elif self.accountchooser.changed:
                 self.collection.change_collection(self.event,
